Imports System.Data
Imports System.Data.OleDb
Public Class frmStudentID
  Dim StudentIDConnection As OleDbConnection
  Dim StudentIDCommand As OleDbCommand
  Dim StudentIDAdapter As OleDbDataAdapter
  Dim StudentIDTable As DataTable
  Dim StudentIDManager As CurrencyManager
  Dim MyState As String
  Dim MyBookmark As Integer

  Private Sub frmStudentID_FormClosing(ByVal sender As Object, ByVal e As System.Windows.Forms.FormClosingEventArgs) Handles Me.FormClosing
    If MyState = "Edit" Or MyState = "Add" Then
      MessageBox.Show("You must finish the current edit before stopping.", "", MessageBoxButtons.OK, MessageBoxIcon.Information)
      e.Cancel = True
    Else
      Try
        'save the update StudentID table
        Dim StudentIDAdapterCommands As New OleDbCommandBuilder(StudentIDAdapter)
        StudentIDAdapter.Update(StudentIDTable)
      Catch ex As Exception
        MessageBox.Show(ex.Message, "Error Saving Database", MessageBoxButtons.OK, MessageBoxIcon.Error)
      End Try
      'close the connection
      StudentIDConnection.Close()
      'dispose of the objects
      StudentIDCommand.Dispose()
      StudentIDAdapter.Dispose()
      StudentIDTable.Dispose()
    End If
  End Sub

  Private Sub frmStudentID_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
    'connect to sales database
    StudentIDConnection = New OleDbConnection("Provider=Microsoft.Jet.OLEDB.4.0; Data Source = " + Application.StartupPath + "\..\..\Student.mdb")
    StudentIDConnection.Open()
    'establish StudentID command object
    StudentIDCommand = New OleDbCommand("SELECT * FROM Students ORDER BY LastName", StudentIDConnection)
    'establish StudentID data adapter/data table
    StudentIDAdapter = New OleDbDataAdapter()
    StudentIDAdapter.SelectCommand = StudentIDCommand
    StudentIDTable = New DataTable()
    StudentIDAdapter.Fill(StudentIDTable)
    'bind controls
    txtFirstName.DataBindings.Add("Text", StudentIDTable, "FirstName")
    txtLastName.DataBindings.Add("Text", StudentIDTable, "LastName")
    lblSex.DataBindings.Add("Text", StudentIDTable, "Sex")
    lblGrade.DataBindings.Add("Text", StudentIDTable, "Grade")
    dtpBirthdate.DataBindings.Add("Text", StudentIDTable, "BirthDate")
    lblPhotoFile.DataBindings.Add("Text", StudentIDTable, "PictureFile")
    'establish currency manager
    StudentIDManager = DirectCast(Me.BindingContext(StudentIDTable), CurrencyManager)
    'show initial photo
    Call ShowUnbound()
    Call SetState("View")
  End Sub
  Private Sub ShowPhoto()
    If lblPhotoFile.Text <> "" Then
      Try
        picItem.Image = Image.FromFile(lblPhotoFile.Text)
      Catch ex As Exception
        MessageBox.Show(ex.Message, "Error Loading Photo", MessageBoxButtons.OK, MessageBoxIcon.Error)
      End Try
    Else
      picItem.Image = Nothing
    End If
  End Sub

  Private Sub btnFirst_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnFirst.Click
    StudentIDManager.Position = 0
    Call ShowUnbound()
  End Sub

  Private Sub btnPrevious_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnPrevious.Click
    StudentIDManager.Position -= 1
    Call ShowUnbound()
  End Sub

  Private Sub btnNext_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnNext.Click
    StudentIDManager.Position += 1
    Call ShowUnbound()
  End Sub

  Private Sub btnLast_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnLast.Click
    StudentIDManager.Position = StudentIDManager.Count - 1
    Call ShowUnbound()
  End Sub
  Private Sub SetState(ByVal AppState As String)
    MyState = AppState
    Select Case AppState
      Case "View"
        btnFirst.Enabled = True
        btnPrevious.Enabled = True
        btnNext.Enabled = True
        btnLast.Enabled = True
        btnEdit.Enabled = True
        btnSave.Enabled = False
        btnCancel.Enabled = False
        btnAdd.Enabled = True
        btnDelete.Enabled = True
        btnPrint.Enabled = True
        btnExit.Enabled = True
        txtFirstName.ReadOnly = True
        txtLastName.ReadOnly = True
        dtpBirthdate.Enabled = False
        btnLoadPhoto.Enabled = False
        grpSex.Enabled = False
        grpGrade.Enabled = False
      Case "Edit", "Add"
        btnFirst.Enabled = False
        btnPrevious.Enabled = False
        btnNext.Enabled = False
        btnLast.Enabled = False
        btnEdit.Enabled = False
        btnSave.Enabled = True
        btnCancel.Enabled = True
        btnAdd.Enabled = False
        btnDelete.Enabled = False
        btnPrint.Enabled = False
        btnExit.Enabled = False
        txtFirstName.ReadOnly = False
        txtLastName.ReadOnly = False
        dtpBirthdate.Enabled = True
        btnLoadPhoto.Enabled = True
        grpSex.Enabled = True
        grpGrade.Enabled = True
    End Select
    txtFirstName.Focus()
  End Sub

  Private Sub btnEdit_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnEdit.Click
    Call SetState("Edit")
  End Sub

  Private Sub btnSave_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnSave.Click
    'Check for Item
    If txtLastName.Text.Trim = "" Then
      MessageBox.Show("You must enter a last name.", "Input Error", MessageBoxButtons.OK, MessageBoxIcon.Information)
      txtLastName.Focus()
      Exit Sub
    End If
    Dim SavedItem As String = txtLastName.Text
    Dim SavedRow As Integer
    StudentIDManager.EndCurrentEdit()
    StudentIDTable.DefaultView.Sort = "LastName"
    SavedRow = StudentIDTable.DefaultView.Find(SavedItem)
    StudentIDManager.Position = SavedRow
    Call ShowUnbound()
    Call SetState("View")
  End Sub

  Private Sub btnCancel_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnCancel.Click
    StudentIDManager.CancelCurrentEdit()
    If MyState = "Add" Then
      StudentIDManager.Position = MyBookmark
    End If
    Call ShowUnbound()
    Call SetState("View")
  End Sub

  Private Sub btnLoadPhoto_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnLoadPhoto.Click
    Try
      If dlgOpen.ShowDialog = Windows.Forms.DialogResult.OK Then
        lblPhotoFile.Text = dlgOpen.FileName
        Call ShowPhoto()
      End If
    Catch ex As Exception
      MessageBox.Show(ex.Message, "Error Opening Photo", MessageBoxButtons.OK, MessageBoxIcon.Error)
    End Try
  End Sub

  Private Sub btnAdd_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnAdd.Click
    MyBookmark = StudentIDManager.Position
    Call SetState("Add")
    StudentIDManager.AddNew()
    'set unbound properties
    rdoMale.Checked = True : lblSex.Text = "M"
    rdoFirst.Checked = True : lblGrade.Text = "1"
    picItem.Image = Nothing
    lblPhotoFile.Text = ""

  End Sub

  Private Sub btnDelete_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnDelete.Click
    If MessageBox.Show("Are you sure you want to delete this record?", "Delete", MessageBoxButtons.YesNo, MessageBoxIcon.Question, MessageBoxDefaultButton.Button2) = Windows.Forms.DialogResult.Yes Then
      StudentIDManager.RemoveAt(StudentIDManager.Position)
      Call ShowUnbound()
    End If
    Call SetState("View")
  End Sub

  Private Sub txtFirstName_KeyPress(ByVal sender As System.Object, ByVal e As System.Windows.Forms.KeyPressEventArgs) Handles txtFirstName.KeyPress
    If e.KeyChar = ControlChars.Cr Then
      txtLastName.Focus()
    End If
  End Sub

  
  Private Sub btnPrint_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnPrint.Click
    'Declare the document
    Dim StudentIDDocument As Drawing.Printing.PrintDocument
    'Create the document and name it
    StudentIDDocument = New Drawing.Printing.PrintDocument()
    StudentIDDocument.DocumentName = "StudentID"
    'Add code handler
    AddHandler StudentIDDocument.PrintPage, AddressOf Me.PrintStudentID
    'Print document in preview control
    Dim SavedPosition As Integer = StudentIDManager.Position
    dlgPreview.Document = StudentIDDocument
    dlgPreview.ShowDialog()
    'Dispose of document when done printing
    StudentIDDocument.Dispose()
    StudentIDManager.Position = SavedPosition
  End Sub
  Private Sub PrintStudentID(ByVal sender As Object, ByVal e As Drawing.Printing.PrintPageEventArgs)
    'draw border
    Dim MyPen As Pen = New Pen(Color.Black, 3)
    e.Graphics.DrawRectangle(MyPen, e.MarginBounds.X, e.MarginBounds.Y, 200, 350)
    Dim MyFont As Font = New Font("Arial", 12, FontStyle.Bold)
    Dim S As String = "Your School Name"
    Dim SSize As SizeF = e.Graphics.MeasureString(S, MyFont)
    e.Graphics.DrawString(S, MyFont, Brushes.Black, e.MarginBounds.X + CInt(0.5 * (200 - SSize.Width)), e.MarginBounds.Y + 15)
    'position picture
    e.Graphics.DrawImage(picItem.Image, e.MarginBounds.X + 25, e.MarginBounds.Y + 50, 150, 200)
    e.HasMorePages = False
    'first/last name/grade
    MyFont = New Font("Arial", 14)
    Dim Y As Integer = e.MarginBounds.Y + 260
    S = txtFirstName.Text
    SSize = e.Graphics.MeasureString(S, MyFont)
    e.Graphics.DrawString(S, MyFont, Brushes.Black, e.MarginBounds.X + CInt(0.5 * (200 - SSize.Width)), Y)
    Y += CInt(MyFont.GetHeight(e.Graphics))
    S = txtLastName.Text
    SSize = e.Graphics.MeasureString(S, MyFont)
    e.Graphics.DrawString(S, MyFont, Brushes.Black, e.MarginBounds.X + CInt(0.5 * (200 - SSize.Width)), Y)
    Y += CInt(MyFont.GetHeight(e.Graphics))
    S = "Grade " + lblGrade.Text
    SSize = e.Graphics.MeasureString(S, MyFont)
    e.Graphics.DrawString(S, MyFont, Brushes.Black, e.MarginBounds.X + CInt(0.5 * (200 - SSize.Width)), Y)
  End Sub

  Private Sub btnExit_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnExit.Click
    Me.Close()
  End Sub
  Private Sub ShowUnbound()
    'sex choice
    If lblSex.Text = "M" Then
      rdoMale.Checked = True
    Else
      rdoFemale.Checked = True
    End If
    'grade choice
    Select Case lblGrade.Text
      Case "1"
        rdoFirst.Checked = True
      Case "2"
        rdoSecond.Checked = True
      Case "3"
        rdoThird.Checked = True
      Case "4"
        rdoFourth.Checked = True
      Case "5"
        rdoFifth.Checked = True
      Case "6"
        rdoSixth.Checked = True
    End Select
    Call ShowPhoto()
  End Sub

  Private Sub rdoSex_CheckedChanged(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles rdoMale.CheckedChanged, rdoFemale.CheckedChanged
    Dim ButtonChecked As RadioButton = CType(sender, RadioButton)
    If ButtonChecked.Text = "Male" Then
      lblSex.Text = "M"
    Else
      lblSex.Text = "F"
    End If
  End Sub

 
  Private Sub rdoGrade_CheckedChanged(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles rdoFirst.CheckedChanged, rdoThird.CheckedChanged, rdoSixth.CheckedChanged, rdoSecond.CheckedChanged, rdoFourth.CheckedChanged, rdoFifth.CheckedChanged
    Dim ButtonChecked As RadioButton = CType(sender, RadioButton)
    Select Case ButtonChecked.Text
      Case "First"
        lblGrade.Text = "1"
      Case "Second"
        lblGrade.Text = "2"
      Case "Third"
        lblGrade.Text = "3"
      Case "Fourth"
        lblGrade.Text = "4"
      Case "Fifth"
        lblGrade.Text = "5"
      Case "Sixth"
        lblGrade.Text = "6"
    End Select
  End Sub

End Class
